@@ -14,7 +14,7 @@ class AllowedValue(CloudFormationLintRule):
     id = 'E3030'
     shortdesc = 'Check if properties have a valid value'
     description = 'Check if properties have a valid value in case of an enumator'
-    source_url = 'https://github.com/aws-cloudformation/cfn-python-lint/blob/master/docs/cfn-resource-specification.md#allowedvalue'
+    source_url = 'https://github.com/aws-cloudformation/cfn-python-lint/blob/main/docs/cfn-resource-specification.md#allowedvalue'
     tags = ['resources', 'property', 'allowed value']
 
     def initialize(self, cfn):
