@@ -13,7 +13,7 @@ class StateMachine(CloudFormationLintRule):
     id = 'E2532'
     shortdesc = 'Check State Machine Definition for proper syntax'
     description = 'Check the State Machine String Definition to make sure its JSON. ' \
-                  'Validate basic syntax of the file to determine validity.'
+        'Validate basic syntax of the file to determine validity.'
     source_url = 'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-stepfunctions-statemachine.html'
     tags = ['resources', 'stepfunctions']
 
@@ -40,15 +40,15 @@ class StateMachine(CloudFormationLintRule):
         ]
         state_key_types = {
             'Pass': ['Result', 'ResultPath', 'Parameters'],
-            'Task': ['Resource', 'ResultPath', 'Retry', 'Catch',
+            'Task': ['Resource', 'ResultPath', 'ResultSelector', 'Retry', 'Catch',
                      'TimeoutSeconds', 'Parameters', 'HeartbeatSeconds'],
             'Map': ['MaxConcurrency', 'Iterator', 'ItemsPath', 'ResultPath',
-                    'Retry', 'Catch', 'Parameters'],
+                    'ResultSelector', 'Retry', 'Catch', 'Parameters'],
             'Choice': ['Choices', 'Default'],
             'Wait': ['Seconds', 'Timestamp', 'SecondsPath', 'TimestampPath'],
             'Succeed': [],
             'Fail': ['Cause', 'Error'],
-            'Parallel': ['Branches', 'ResultPath', 'Retry', 'Catch']
+            'Parallel': ['Branches', 'ResultPath', 'ResultSelector', 'Parameters', 'Retry', 'Catch']
         }
         state_required_types = {
             'Pass': [],
